@@ -117,6 +117,20 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
 
     n_comps_found_ : int, defaults to n_components
         The number of components found by the fit.
+
+        centers_array_ : array-like, shape (n_components, 9)
+        An array containing the centers of each component and
+        their uncertainties in each of the 4 coordinate dimensions,
+        as well as the cluster uncertainty.
+        
+    ips_ : array-like, shape (n_components,)
+        The number of ions in each cluster.
+
+    unique_labels_ : array-like, shape (n_components,)
+        The labels used in the clustering fit.
+
+    colors_ : list, len = n_components
+        A list of the colors of each cluster.
     """
 
     def __init__(self, n_components=1, *, cov_type='full', tol=1e-5,
@@ -360,7 +374,6 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
         c2_sigma_err, c2_height_abs, c2_height_err, c2_fw_hm_abs, \
         c2_fw_hm_err = [], [], [], [], [], [], [], [], [], []
         cluster_err = []
-        ips = []
 
         c1_clusters, c2_clusters = {}, {}  # all c1's and c2's of the
         # ion-hits in each cluster
@@ -403,7 +416,6 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
                 c2_fw_hm_abs.append(0)
                 c2_fw_hm_err.append(0)
 
-                ips.append(len(c1_cut))
                 cluster_err.append(0)
 
             else:
@@ -830,7 +842,7 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
         n_samples = len(data_array[:, 0])
         center_array = self.centers_array_
 
-        fig = plt.figure(figsize=(9, 9))
+        fig = plt.figure()
         ax = plt.subplot(111, aspect='equal')
         axs = plt.gca()
 
