@@ -2,6 +2,7 @@
 
 # Author: Wei Xue <xuewei4d@gmail.com>
 # Modified by Thierry Guillemot <thierry.guillemot.work@gmail.com>
+# Modified by Colin Weber <colin.weber.27@gmail.com>
 # License: BSD 3 clause
 
 import numpy as np
@@ -301,6 +302,8 @@ def _estimate_gaussian_covariances_spherical(resp, X, nk, means, reg_covar):
 def _phase_constrained_estimate_gaussian_parameters(X, resp, reg_covar, covariance_type, phases):
     """Estimate the Gaussian distribution parameters.
 
+    Written by Colin Weber.
+
     Parameters
     ----------
     X : array-like, shape (n_samples, n_features)
@@ -498,16 +501,20 @@ def _estimate_log_gaussian_prob(X, means, precisions_chol, covariance_type):
 
 
 class PhaseConstrainedGaussianMixture(PhaseConstrainedBaseMixture):
-    """Gaussian Mixture.
+    """Phase First Gaussian Mixture.
 
-    Representation of a Gaussian mixture model probability distribution.
-    This class allows to estimate the parameters of a Gaussian mixture
-    distribution.
+    This class implements the Phase First Gaussian mixture fit.
+    While fitting to a dataset in polar coordinates, the phase dimension is fit to
+    first, followed by a GMM fit to both spatial dimensions
+    in which the phase dimension of the component means is
+    fixed. This type of fit was found to work especially
+    well with data sets in which there were many species,
+    like the 168Ho data.
+
+    .. version:: 0.1
 
     Read more in the :ref:`User Guide <gmm>`.
 
-    .. versionadded:: 0.18
-
     Parameters
     ----------
     n_components : int, defaults to 1.
@@ -738,6 +745,8 @@ class PhaseConstrainedGaussianMixture(PhaseConstrainedBaseMixture):
     def _phase_constrained_m_step(self, X, log_resp):
         """M step.
 
+        Written by Colin Weber.
+
         Parameters
         ----------
         X : array-like, shape (n_samples, n_features)
